@@ -84,7 +84,7 @@ templateObjectSchema = atapi.Schema((
         name='tableListingFields',
         required=0,
         searchable=0,
-        default=('title', 'description'),
+        default=(),
         schemata='hacks'
     ),
 
@@ -199,6 +199,8 @@ class MegamanicEditableTemplateObject(MegamanicEditable):
     def manage_afterAdd(self, item, container):
         """Adds necessary things.."""
         # Why AT default doesn't kick in beats me
+        self.setTableListingFields((self.getId() + '_title',
+                                    self.getId() + '_description'))
         try:
             try:
                 self.invokeFactory(id='added', type_name='Large Plone Folder', title='Add Objects')
